@@ -173,7 +173,7 @@ def clean_outofbounds(data, bounds, col=['Lng', 'Lat']):
     lon1, lat1, lon2, lat2 = bounds
     if (lon1 > lon2) | (lat1 > lat2) | (abs(lat1) > 90) | (
             abs(lon1) > 180) | (abs(lat2) > 90) | (abs(lon2) > 180):
-        raise Exception(
+        raise Exception(  # pragma: no cover
             'Bounds error. The input bounds should be in the order \
 of [lon1,lat1,lon2,lat2]. (lon1,lat1) is the lower left corner and \
 (lon2,lat2) is the upper right corner.')
@@ -308,8 +308,8 @@ def dataagg(data, shape, col=['Lng', 'Lat', 'count'], accuracy=500):
         The zone-matched data
     '''
     if len(col) == 2:
-        Lng, Lat = col
-        aggcol = None
+        Lng, Lat = col  # pragma: no cover
+        aggcol = None  # pragma: no cover
     else:
         Lng, Lat, aggcol = col
     shape['index'] = range(len(shape))
@@ -329,10 +329,10 @@ def dataagg(data, shape, col=['Lng', 'Lat', 'count'], accuracy=500):
         aggresult = pd.merge(shape, data1.groupby('index')[
                              aggcol].sum().reset_index()).drop('index', axis=1)
     else:
-        data1['_'] = 1
-        aggresult = pd.merge(shape, data1.groupby('index')['_'].sum().rename(
+        data1['_'] = 1  # pragma: no cover
+        aggresult = pd.merge(shape, data1.groupby('index')['_'].sum().rename(  # pragma: no cover
             'count').reset_index()).drop('index', axis=1)
-        data1 = data1.drop('_', axis=1)
+        data1 = data1.drop('_', axis=1)  # pragma: no cover
     data1 = data1.drop('index', axis=1)
     return aggresult, data1
 
